# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-05-24 14:03
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fido', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='u2fdevice',
            name='attestation',
            field=models.TextField(blank=True, default=None, null=True),
        ),
    ]



"""URLs for django_fido application tests."""
from django.conf.urls import include, url
from django.contrib import admin

urlpatterns = [
    url('', include('django_fido.urls')),
    url('admin/', admin.site.urls),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-21 11:20
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fido', '0006_fill_empty_attestation'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authenticator',
            name='attestation_data',
            field=models.TextField(),
        ),
    ]
